
# Type: macromolecular machine to cellular component association_object




URI: [biolink:macromolecular_machine_to_cellular_component_association_object](https://w3id.org/biolink/vocab/macromolecular_machine_to_cellular_component_association_object)


## Domain and Range

[MacromolecularMachineToCellularComponentAssociation](MacromolecularMachineToCellularComponentAssociation.md) ->  <sub>REQ</sub> [CellularComponent](CellularComponent.md)

## Parents

 *  is_a: [functional association➞object](functional_association_object.md)

## Children


## Used by

 * [MacromolecularMachineToCellularComponentAssociation](MacromolecularMachineToCellularComponentAssociation.md)
